{% extends "base.html" %}

{% block title %}Add Users{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">


    <div class="form-group">

        <div class="card generic-card">
            <div class="card-header generic-card-header">
                <h4>Invite Users</h4>
            </div>
            <div class="card-body">
                <div class="form-group">
                    <div class="row mb-3">
                        <div class="col">
                            STEP 1: Users sign up at: <strong>{{ signup_page }}</strong>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col">
                            STEP 2: When prompted, users enter the school code : <strong>{{ school_code }}</strong>
                        </div>
                    </div>
                </div>
            </div>
        </div>

    </div>

    <div class="form-group">
        <a href="{% url 'core_nav:settings' %}" class="btn btn-secondary" role="button">Done</a>
    </div>

    </div>
    </main>

{% endblock %}
