# Generated by Django 2.2.4 on 2019-09-15 14:59

import django.db.models.deletion
import schools.models
from django.db import migrations, models



class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Authority',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('authority_name', models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='School',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('school_name', models.CharField(default='', max_length=150)),
                ('school_type', models.CharField(choices=[('Primary', 'Primary school'), ('Secondary', 'Secondary school'), ('All', 'All through 5-18 school')], default='Primary', max_length=150)),
                ('active_account', models.BooleanField(default=True)),
                ('account_expiry', models.DateField(blank=True, default=schools.models.expiry_plus_28_days)),
                ('account_type', models.CharField(choices=[('Test', 'Test'), ('Demo', 'Demo'), ('Full', 'Full')], default='Full', max_length=10)),
                ('postcode', models.CharField(blank=True, default='', max_length=8)),
                ('is_departmental_school', models.BooleanField(default=False)),
                ('school_badge', models.ImageField(blank=True, null=True, upload_to=schools.models.BadgeUploadPath())),
                ('self_evaluation_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('stakeholder_surveys_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('improvement_plan_last_visit', models.DateField(blank=True, default=None, null=True)),
                ('authority', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='schools.Authority')),
            ],
        ),
        migrations.CreateModel(
            name='Faculty',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('faculty_name', models.CharField(default='', max_length=100)),
                ('owner', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='schools.School')),
            ],
        ),
    ]
