# Generated by Django 2.2.4 on 2021-04-04 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0004_subscription_user'),
    ]

    operations = [
        migrations.AddField(
            model_name='school',
            name='school_code',
            field=models.CharField(default='--------', max_length=8),
        ),
    ]
