# Generated by Django 2.2.4 on 2021-04-03 13:35

import schools.models
from django.db import migrations, models



class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0002_subscription'),
    ]

    operations = [
        migrations.AddField(
            model_name='subscription',
            name='expiry',
            field=models.DateField(blank=True, default=schools.models.expiry_plus_28_days),
        ),
    ]
