{% extends "generic-base.html" %}

{% block title %}IMPACT - Delete Department{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <form method="post" action="">
    {% csrf_token %}

    <div class="form-group">
    <div class="card generic-card-card">
        <div class="card-header generic-card-header">
            <h4>Delete Department</h4>
        </div>
        <div class="card-body">

            <div class="form-group">
            Are you sure you want to delete the following department / faculty:
            </div>
            <div class="form-group">
            {{ object }}
            </div>
            <div class="form-group">
            <strong>Warning! </strong>This will delete all Stakeholder Surveys produced by the department.
            </div>
        </div>
    </div>
    </div>

    <div class="form-group">
        <button class="btn btn-warning" name="delete" value="delete">Delete</button>
        <button class="btn btn-secondary" name="cancel" value="delete">Cancel</button>
    </div>

    </form>

    </div>

    </main>
{% endblock %}

