{% extends "default-base.html" %}

    {% block title %}IMPACT - Join Department{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <form action="" method="post">
    {% csrf_token %}

    <div class="form-group">

    <div class="card generic-card-card">
        <div class="card-header generic-card-header">
            <h4>Join Department</h4>
        </div>
        <div class="card-body">
            <div class="form-group">
                <div class="row">
                <div class="col col-sm-5">
                    <label for="ip-email">Which department would you like to join?</label>
                    {{ department_form.faculty }}
                    {{ department_form.faculty.errors }}
                </div>
                </div>
            </div>
        </div>
    </div>
    </div>



    <div class="form-group">
        <button type="submit" class="btn btn-success" name="save" value="Save">Join</button>
        <button type="submit" class="btn btn-primary" name="cancel" formnovalidate value="Cancel">Cancel</button>
    </div>
    </form>

    </div>

    </main>

{% endblock %}

