{% extends "generic-base.html" %}

    {% block title %}IMPACT - Create Department{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <form method="post" action="">
    {% csrf_token %}

    <div class="form-group">
    <div class="card generic-card-card">
        <div class="card-header generic-card-header">
            <h4>{{ card_title }}</h4>
        </div>
        <div class="card-body">
            <div class="form-group">
                <label for="ip-name">What is name of the Department?</label>
                {{ new_department_form.faculty_name }}
            </div>
        </div>
    </div>
    </div>


    <div class="form-group">
        <button type="submit" class="btn btn-success" name="save_faculty" value="Save">Save</button>
        <button type="submit" class="btn btn-primary" name="cancel" formnovalidate value="Cancel">Cancel</button>
    </div>

    </form>
    </div>
    </main>

{% endblock %}

