{% extends "default-base.html" %}

    {% block title %}IMPACT - Upload Logo{% endblock %}

{% block content %}

    <main role="main" class="content">
	<div class="container">

    <form method="post" enctype="multipart/form-data">
    {% csrf_token %}

    <div class="form-group">
          <div class="card generic-card-card">
            <div class="card-header generic-card-header">
                <h4>Upload School Logo</h4>
            </div>
            <div class="card-body">
                <div class="form-group">
                    {% if school_badge_url is not None %}
                        <img src="{{ school_badge_url }}" width="250" height="250">
                    {% else %}
                        <p>No school logo uploaded</p>
                    {% endif %}
                </div>

                <div class="form-group">
                    {{ school_badge_form.school_badge }}
                </div>

                <div class="form-group">
                    <p>Recommended image size: square, at least 250 x 250 pixels</p>
                </div>
            </div>
          </div>
    </div>


    <div class="form-group">
        <button type="submit" class="btn btn-primary" name="upload_badge" value="Upload">Upload Logo</button>
        <a href="{% url 'core_nav:settings' %}" class="btn btn-primary" role="button">Done</a>
    </div>

    </form>
    </div>

    </main>

{% endblock %}
